Final Lab
=========

Network Topology
----------------

![Network topology](figures/topology.png)

Requirements
------------

1.  A document with addressing table (device, interface, IP address/prefix
    length) should be provided.
2.  PPP should be used at R2-R3 and R3-R4 links. Secure PPP authentication
    method should be configured.
3.  R3 (ISP) should have routes to directly connected networks only (i.e. ISP
    knows nothing about customer's private networks).
4.  Branch #1 and Branch #2 networks should be connected via site-to-site VPN.
5.  S2 is a L3 switch. S2 should be configured with static routes only (it does
    not participate in OSPF protocol).
6.  R1, R4, R5, R6 should receive information about routes to VLAN A and VLAN B
    via OSPF protocol.
7.  OSPF passive interfaces should be properly configured.
8.  PC1, PC2, PC4, PC5, PC6 should receive network configuration via DHCP. R2 is
    a DHCP server for VLAN A and VLAN B. R4 is a DHCP server for VLAN C and
    VLAN D.
9.  R5 and R6 should implement HSRP.
10. S5 and S6 should be connected with LACP based link aggregation.
11. Server and all PCs from Branch #1 and Branch #2 networks should be able to
    access the Internet (PC3).
12. Server should be accessible from the Internet (PC3).

PPP Links on EVE
----------------

EVE software doesn't support serial links and therefore PPP. PPPoE should be
used instead.

An example of PPPoE server configuration for the Branch #1 link:

```
interface Virtual-Template 1
    ip address <IP address> <subnet mask>
    exit

bba-group pppoe BRANCH1_GROUP
    virtual-template 1
    exit

interface GigabitEthernet 0/2
    pppoe enable group BRANCH1_GROUP
    no shutdown
    exit
```

An example of PPPoE client configuration:

```
interface Dialer1
    ip address <IP address> <subnet mask>
    encapsulation ppp
    dialer pool 1
    exit

interface GigabitEthernet0/0
    pppoe enable
    pppoe-client dial-pool-number 1
    no shutdown
    exit
```

Enabling Layer 3 Features on a Switch
-------------------------------------

L3 features are already enabled on EVE switches (Cisco vIOS L2 nodes).

On Catalist 2960 series switches L3 features have to be enabled with the
following commands:

```
Switch(config)# sdm prefer lanbase-routing
Switch(config)# exit
Switch# copy running-config startup-config
Switch# reload
```

Refer to [Lab "L3 switch + DHCP"][L3 Switch Lab] for details on L3 switch
configuration.

[L3 Switch Lab]: http://ibks.spbstu.ru:8443/StudyProc/CiscoLabs/ccna-routing-and-switching/2-routing-switching-essentials/8-dhcp/dhcp/Lab%20L3%20Switch%20+%20DHCP.pdf

Known Packet Tracer Issues
--------------------------

*   Tunnel interface turns down (`line protocol is down`) with the following error:

    ```
    %TUN-5-RECURDOWN: 0 temporarily disabled due to recursive routing
    ```

    when `default-information originate` OSFP setting is used. This happens due
    to incorrect handling of administrative distance of 0.0.0.0/0 route that is
    received via OSPF.

    As a workaround, use static default routes instead of
    `default-information originate` OSFP setting.

*   PC4, PC5, PC6 may fail to receive configuration via DHCP.

    As a workaround, temporarily remove the link between S5 and R5 (or S6 and R6)
    util DHCP exchange is completed.
